summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xsrc/API/web_provider_plugin_info.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/API/web_provider_plugin_info.cpp b/src/API/web_provider_plugin_info.cpp
index 56024df..373c95f 100755
--- a/src/API/web_provider_plugin_info.cpp
+++ b/src/API/web_provider_plugin_info.cpp
@@ -58,7 +58,7 @@ static const std::string jsonMemberBoxSize("supported_size");
static const std::string jsonValueBoolTrue("true");
static const std::string jsonValueBoolFalse("false");
static const std::string jsonFileExtension(".json");
-static const std::string mendatoryBoxSize("1x1");
+static const std::string mandatoryBoxSize("1x1");
web_provider_plugin_info** web_provider_plugin_get_installed_list(int* count)
{
@@ -315,14 +315,14 @@ int web_provider_plugin_check_supported_size(
}
// compare the parsed config data with the parsed json data
- bool mendatoryCheck = false;
+ bool mandatoryCheck = false;
for (int configCnt = 0; configCnt < sizeCount; configCnt++) {
bool supportedSizeCheck = false;
for (int jsonCnt = 0; jsonCnt < jsonData->box_size_count; jsonCnt++) {
- // check mendatory size
- if (isDefaultType && !strcmp(mendatoryBoxSize.c_str(), size[configCnt])) {
- mendatoryCheck = true;
+ // check mandatory size
+ if (isDefaultType && !strcmp(mandatoryBoxSize.c_str(), size[configCnt])) {
+ mandatoryCheck = true;
}
// check supported size
@@ -341,7 +341,7 @@ int web_provider_plugin_check_supported_size(
//release the jsonData
web_provider_plugin_release_info(jsonData);
- if (isDefaultType && !mendatoryCheck) {
+ if (isDefaultType && !mandatoryCheck) {
LogD("Mandatory members don't exist ");
return false;
}